search Package
==============

:mod:`search` Package
---------------------

.. automodule:: stoqlib.gui.search
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`callsearch` Module
------------------------

.. automodule:: stoqlib.gui.search.callsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`categorysearch` Module
----------------------------

.. automodule:: stoqlib.gui.search.categorysearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`commissionsearch` Module
------------------------------

.. automodule:: stoqlib.gui.search.commissionsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`consignmentsearch` Module
-------------------------------

.. automodule:: stoqlib.gui.search.consignmentsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`eventsearch` Module
-------------------------

.. automodule:: stoqlib.gui.search.eventsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fiscalsearch` Module
--------------------------

.. automodule:: stoqlib.gui.search.fiscalsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loansearch` Module
------------------------

.. automodule:: stoqlib.gui.search.loansearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parametersearch` Module
-----------------------------

.. automodule:: stoqlib.gui.search.parametersearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentsearch` Module
---------------------------

.. automodule:: stoqlib.gui.search.paymentsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`personsearch` Module
--------------------------

.. automodule:: stoqlib.gui.search.personsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`productionsearch` Module
------------------------------

.. automodule:: stoqlib.gui.search.productionsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`productsearch` Module
---------------------------

.. automodule:: stoqlib.gui.search.productsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`profilesearch` Module
---------------------------

.. automodule:: stoqlib.gui.search.profilesearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchasesearch` Module
----------------------------

.. automodule:: stoqlib.gui.search.purchasesearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`receivingsearch` Module
-----------------------------

.. automodule:: stoqlib.gui.search.receivingsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`salesearch` Module
------------------------

.. automodule:: stoqlib.gui.search.salesearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sellablesearch` Module
----------------------------

.. automodule:: stoqlib.gui.search.sellablesearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sellableunitsearch` Module
--------------------------------

.. automodule:: stoqlib.gui.search.sellableunitsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`servicesearch` Module
---------------------------

.. automodule:: stoqlib.gui.search.servicesearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stationsearch` Module
---------------------------

.. automodule:: stoqlib.gui.search.stationsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockdecreasesearch` Module
---------------------------------

.. automodule:: stoqlib.gui.search.stockdecreasesearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`taxclasssearch` Module
----------------------------

.. automodule:: stoqlib.gui.search.taxclasssearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tillsearch` Module
------------------------

.. automodule:: stoqlib.gui.search.tillsearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transfersearch` Module
----------------------------

.. automodule:: stoqlib.gui.search.transfersearch
    :members:
    :undoc-members:
    :show-inheritance:

